@@ -5,7 +5,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! fern = { version = "0.5", features = ["colored"] }
+//! fern = { version = "0.6", features = ["colored"] }
 //! ```
 //!
 //! ---
@@ -48,12 +48,12 @@
 //!
 //! ---
 //!
-//! Coloring levels is nice, but the alternative is good to. For an example
+//! Coloring levels is nice, but the alternative is good too. For an example of an
 //! application coloring each entire log line with the right color, see
 //! [examples/pretty-colored.rs][ex].
 //!
 //! [`ColoredLevelConfig`]: struct.ColoredLevelConfig.html
-//! [ex]: https://github.com/daboross/fern/blob/master/examples/pretty-colored.rs
+//! [ex]: https://github.com/daboross/fern/blob/fern-0.6.1/examples/pretty-colored.rs
 use std::fmt;
 
 pub use colored::Color;
@@ -281,13 +281,13 @@ impl ColoredLogLevel for Level {
 }
 
 #[cfg(test)]
+#[cfg(not(windows))]
 mod test {
     use colored::{Color::*, Colorize};
 
     use super::WithFgColor;
 
     #[test]
-    #[cfg(not(windows))]
     fn fg_color_matches_colored_behavior() {
         for &color in &[
             Black,
@@ -307,6 +307,7 @@ mod test {
             BrightCyan,
             BrightWhite,
         ] {
+            colored::control::SHOULD_COLORIZE.set_override(true);
             assert_eq!(
                 format!("{}", "test".color(color)),
                 format!(
@@ -321,7 +322,6 @@ mod test {
     }
 
     #[test]
-    #[cfg(not(windows))]
     fn fg_color_respects_formatting_flags() {
         let s = format!(
             "{:^8}",
