@@ -1,5 +1,5 @@
 #![deny(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/fern/0.6.0")]
+#![doc(html_root_url = "https://docs.rs/fern/0.6.1")]
 //! Efficient, configurable logging in Rust.
 //!
 //! # Depending on fern
@@ -9,7 +9,7 @@
 //! ```toml
 //! [dependencies]
 //! log = "0.4"
-//! fern = "0.5"
+//! fern = "0.6"
 //! ```
 //!
 //! # Example setup
@@ -193,8 +193,8 @@
 //! [time-and-date docs]: https://docs.rs/chrono/0.4/chrono/index.html#date-and-time
 //! [the format specifier docs]: https://docs.rs/chrono/0.4/chrono/format/strftime/index.html#specifiers
 //! [`Dispatch` documentation]: struct.Dispatch.html
-//! [full example program]: https://github.com/daboross/fern/tree/master/examples/cmd-program.rs
-//! [syslog full example program]: https://github.com/daboross/fern/tree/master/examples/syslog.rs
+//! [full example program]: https://github.com/daboross/fern/tree/fern-0.6.1/examples/cmd-program.rs
+//! [syslog full example program]: https://github.com/daboross/fern/tree/fern-0.6.1/examples/syslog.rs
 //! [`apply`]: struct.Dispatch.html#method.apply
 //! [colors]: colors/index.html
 //! [syslog]: syslog/index.html
@@ -250,6 +250,12 @@ type Syslog4Rfc5424Logger = syslog4::Logger<
     syslog4::Formatter5424,
 >;
 
+#[cfg(all(not(windows), feature = "syslog-6"))]
+type Syslog6Rfc3164Logger = syslog6::Logger<syslog6::LoggerBackend, syslog6::Formatter3164>;
+
+#[cfg(all(not(windows), feature = "syslog-6"))]
+type Syslog6Rfc5424Logger = syslog6::Logger<syslog6::LoggerBackend, syslog6::Formatter5424>;
+
 /// Convenience method for opening a log file with common options.
 ///
 /// Equivalent to:
@@ -291,11 +297,14 @@ pub fn log_file<P: AsRef<Path>>(path: P) -> io::Result<File> {
 /// See [`OpenOptions`] for more information.
 ///
 /// [`OpenOptions`]: https://doc.rust-lang.org/std/fs/struct.OpenOptions.html
+///
+/// This function is not available on Windows, and it requires the `reopen-03`
+/// feature to be enabled.
 #[cfg(all(not(windows), feature = "reopen-03"))]
 #[inline]
-pub fn log_reopen(path: &Path, signal: Option<libc::c_int>) -> io::Result<reopen::Reopen<File>> {
+pub fn log_reopen(path: &Path, signal: Option<libc::c_int>) -> io::Result<reopen03::Reopen<File>> {
     let p = path.to_owned();
-    let r = reopen::Reopen::new(Box::new(move || log_file(&p)))?;
+    let r = reopen03::Reopen::new(Box::new(move || log_file(&p)))?;
 
     if let Some(s) = signal {
         if let Err(e) = r.handle().register_signal(s) {
@@ -304,3 +313,35 @@ pub fn log_reopen(path: &Path, signal: Option<libc::c_int>) -> io::Result<reopen
     }
     Ok(r)
 }
+
+/// Convenience method for opening a re-openable log file with common options.
+///
+/// The file opening is equivalent to:
+///
+/// ```no_run
+/// std::fs::OpenOptions::new()
+///     .write(true)
+///     .create(true)
+///     .append(true)
+///     .open("filename")
+/// # ;
+/// ```
+///
+/// See [`OpenOptions`] for more information.
+///
+/// [`OpenOptions`]: https://doc.rust-lang.org/std/fs/struct.OpenOptions.html
+///
+/// This function requires the `reopen-1` feature to be enabled.
+#[cfg(all(not(windows), feature = "reopen-1"))]
+#[inline]
+pub fn log_reopen1<S: IntoIterator<Item = libc::c_int>>(path: &Path, signals: S)
+    -> io::Result<reopen1::Reopen<File>>
+{
+    let p = path.to_owned();
+    let r = reopen1::Reopen::new(Box::new(move || log_file(&p)))?;
+
+    for s in signals {
+        r.handle().register_signal(s)?;
+    }
+    Ok(r)
+}
