@@ -19,8 +19,12 @@ use crate::{Filter, Formatter};
 
 #[cfg(all(not(windows), feature = "syslog-4"))]
 use crate::{Syslog4Rfc3164Logger, Syslog4Rfc5424Logger};
+#[cfg(all(not(windows), feature = "syslog-6"))]
+use crate::{Syslog6Rfc3164Logger, Syslog6Rfc5424Logger};
 #[cfg(all(not(windows), feature = "reopen-03"))]
-use reopen;
+use reopen03;
+#[cfg(all(not(windows), feature = "reopen-1"))]
+use reopen1;
 
 pub enum LevelConfiguration {
     JustDefault,
@@ -68,6 +72,10 @@ pub enum Output {
     Syslog4Rfc3164(Syslog4Rfc3164),
     #[cfg(all(not(windows), feature = "syslog-4"))]
     Syslog4Rfc5424(Syslog4Rfc5424),
+    #[cfg(all(not(windows), feature = "syslog-6"))]
+    Syslog6Rfc3164(Syslog6Rfc3164),
+    #[cfg(all(not(windows), feature = "syslog-6"))]
+    Syslog6Rfc5424(Syslog6Rfc5424),
     Dispatch(Dispatch),
     SharedDispatch(Arc<Dispatch>),
     OtherBoxed(Box<dyn Log>),
@@ -78,6 +86,8 @@ pub enum Output {
     DateBased(DateBased),
     #[cfg(all(not(windows), feature = "reopen-03"))]
     Reopen(Reopen),
+    #[cfg(all(not(windows), feature = "reopen-1"))]
+    Reopen1(Reopen1),
 }
 
 pub struct Stdout {
@@ -107,7 +117,13 @@ pub struct Writer {
 
 #[cfg(all(not(windows), feature = "reopen-03"))]
 pub struct Reopen {
-    pub stream: Mutex<reopen::Reopen<fs::File>>,
+    pub stream: Mutex<reopen03::Reopen<fs::File>>,
+    pub line_sep: Cow<'static, str>,
+}
+
+#[cfg(all(not(windows), feature = "reopen-1"))]
+pub struct Reopen1 {
+    pub stream: Mutex<reopen1::Reopen<fs::File>>,
     pub line_sep: Cow<'static, str>,
 }
 
@@ -131,6 +147,21 @@ pub struct Syslog4Rfc5424 {
     >,
 }
 
+#[cfg(all(not(windows), feature = "syslog-6"))]
+pub struct Syslog6Rfc3164 {
+    pub inner: Mutex<Syslog6Rfc3164Logger>,
+}
+
+#[cfg(all(not(windows), feature = "syslog-6"))]
+pub struct Syslog6Rfc5424 {
+    pub inner: Mutex<Syslog6Rfc5424Logger>,
+    pub transform: Box<
+        dyn Fn(&log::Record) -> (u32, HashMap<String, HashMap<String, String>>, String)
+            + Sync
+            + Send,
+    >,
+}
+
 pub struct Panic;
 
 pub struct Null;
@@ -310,12 +341,18 @@ impl Log for Output {
             Output::Syslog4Rfc3164(ref s) => s.enabled(metadata),
             #[cfg(all(not(windows), feature = "syslog-4"))]
             Output::Syslog4Rfc5424(ref s) => s.enabled(metadata),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            Output::Syslog6Rfc3164(ref s) => s.enabled(metadata),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            Output::Syslog6Rfc5424(ref s) => s.enabled(metadata),
             Output::Panic(ref s) => s.enabled(metadata),
             Output::Writer(ref s) => s.enabled(metadata),
             #[cfg(feature = "date-based")]
             Output::DateBased(ref s) => s.enabled(metadata),
             #[cfg(all(not(windows), feature = "reopen-03"))]
             Output::Reopen(ref s) => s.enabled(metadata),
+            #[cfg(all(not(windows), feature = "reopen-1"))]
+            Output::Reopen1(ref s) => s.enabled(metadata),
         }
     }
 
@@ -335,12 +372,18 @@ impl Log for Output {
             Output::Syslog4Rfc3164(ref s) => s.log(record),
             #[cfg(all(not(windows), feature = "syslog-4"))]
             Output::Syslog4Rfc5424(ref s) => s.log(record),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            Output::Syslog6Rfc3164(ref s) => s.log(record),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            Output::Syslog6Rfc5424(ref s) => s.log(record),
             Output::Panic(ref s) => s.log(record),
             Output::Writer(ref s) => s.log(record),
             #[cfg(feature = "date-based")]
             Output::DateBased(ref s) => s.log(record),
             #[cfg(all(not(windows), feature = "reopen-03"))]
             Output::Reopen(ref s) => s.log(record),
+            #[cfg(all(not(windows), feature = "reopen-1"))]
+            Output::Reopen1(ref s) => s.log(record),
         }
     }
 
@@ -360,12 +403,18 @@ impl Log for Output {
             Output::Syslog4Rfc3164(ref s) => s.flush(),
             #[cfg(all(not(windows), feature = "syslog-4"))]
             Output::Syslog4Rfc5424(ref s) => s.flush(),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            Output::Syslog6Rfc3164(ref s) => s.flush(),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            Output::Syslog6Rfc5424(ref s) => s.flush(),
             Output::Panic(ref s) => s.flush(),
             Output::Writer(ref s) => s.flush(),
             #[cfg(feature = "date-based")]
             Output::DateBased(ref s) => s.flush(),
             #[cfg(all(not(windows), feature = "reopen-03"))]
             Output::Reopen(ref s) => s.flush(),
+            #[cfg(all(not(windows), feature = "reopen-1"))]
+            Output::Reopen1(ref s) => s.flush(),
         }
     }
 }
@@ -573,6 +622,9 @@ writer_log_impl!(Writer);
 #[cfg(all(not(windows), feature = "reopen-03"))]
 writer_log_impl!(Reopen);
 
+#[cfg(all(not(windows), feature = "reopen-1"))]
+writer_log_impl!(Reopen1);
+
 impl Log for Sender {
     fn enabled(&self, _: &log::Metadata) -> bool {
         true
@@ -592,7 +644,7 @@ impl Log for Sender {
     fn flush(&self) {}
 }
 
-#[cfg(any(feature = "syslog-3", feature = "syslog-4"))]
+#[cfg(all(not(windows), any(feature = "syslog-3", feature = "syslog-4", feature = "syslog-6")))]
 macro_rules! send_syslog {
     ($logger:expr, $level:expr, $message:expr) => {
         use log::Level;
@@ -658,6 +710,42 @@ impl Log for Syslog4Rfc5424 {
     fn flush(&self) {}
 }
 
+#[cfg(all(not(windows), feature = "syslog-6"))]
+impl Log for Syslog6Rfc3164 {
+    fn enabled(&self, _: &log::Metadata) -> bool {
+        true
+    }
+
+    fn log(&self, record: &log::Record) {
+        fallback_on_error(record, |record| {
+            let message = record.args().to_string();
+            let mut log = self.inner.lock().unwrap_or_else(|e| e.into_inner());
+            send_syslog!(log, record.level(), message);
+
+            Ok(())
+        });
+    }
+    fn flush(&self) {}
+}
+
+#[cfg(all(not(windows), feature = "syslog-6"))]
+impl Log for Syslog6Rfc5424 {
+    fn enabled(&self, _: &log::Metadata) -> bool {
+        true
+    }
+
+    fn log(&self, record: &log::Record) {
+        fallback_on_error(record, |record| {
+            let transformed = (self.transform)(record);
+            let mut log = self.inner.lock().unwrap_or_else(|e| e.into_inner());
+            send_syslog!(log, record.level(), transformed);
+
+            Ok(())
+        });
+    }
+    fn flush(&self) {}
+}
+
 impl Log for Panic {
     fn enabled(&self, _: &log::Metadata) -> bool {
         true
@@ -768,6 +856,8 @@ enum LogError {
     Send(mpsc::SendError<String>),
     #[cfg(all(not(windows), feature = "syslog-4"))]
     Syslog4(syslog4::Error),
+    #[cfg(all(not(windows), feature = "syslog-6"))]
+    Syslog6(syslog6::Error),
 }
 
 impl fmt::Display for LogError {
@@ -777,6 +867,8 @@ impl fmt::Display for LogError {
             LogError::Send(ref e) => write!(f, "{}", e),
             #[cfg(all(not(windows), feature = "syslog-4"))]
             LogError::Syslog4(ref e) => write!(f, "{}", e),
+            #[cfg(all(not(windows), feature = "syslog-6"))]
+            LogError::Syslog6(ref e) => write!(f, "{}", e),
         }
     }
 }
@@ -800,6 +892,13 @@ impl From<syslog4::Error> for LogError {
     }
 }
 
+#[cfg(all(not(windows), feature = "syslog-6"))]
+impl From<syslog6::Error> for LogError {
+    fn from(error: syslog6::Error) -> Self {
+        LogError::Syslog6(error)
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::LevelConfiguration;
